# Preliminaries 

# before running the code please uncomment the following line to recover the
# environment and follow the prompts in the console
# renv::restore()

library(factoextra)
library(GGally)

## Figure 1:  Share of Pressure ---------------------------------------

Footprints_inTrade <- readRDS("Outputs/Footprints_inTrade.rds")
View(Footprints_inTrade)

## Figure 2: Income groups -------------------------------------------

# Figure 2: Trade pressure on the planetary boundaries exerted by different income groups of countries

# read needed data

Fertilizers_inTrade_byctr <- readRDS("Outputs/Fertilizers_inTrade_byctr.rds")
Land_use_inTrade_byctr <- readRDS("Outputs/Land_use_inTrade_byctr.rds")
Biodiversity_loss_inTrade_byctr <- readRDS("Outputs/Biodiversity_loss_inTrade_byctr.rds")
Blue_water_consumption_inTrade_byctr <- readRDS("Outputs/Blue_water_consumption_inTrade_byctr.rds")
Water_stress_inTrade_byctr <- readRDS("Outputs/Water_stress_inTrade_byctr.rds")
GHG_Emissions_inTrade_byctr <- readRDS("Outputs/GHG_Emissions_inTrade_byctr.rds")
Chemicals_inTrade_byctr <- readRDS("Outputs/Chemicals_inTrade_byctr.rds")

# Pre-defined indices dividing high, middle and low-income countries: 

high_indices <- unique(c(8,11,12,15,20,21,27,31,32,33,42,43,44,47,
                         53,54,56,57,59,65,68,69,71,74,77,78,79,82,
                         87,88,94,95,96,103,114,115,117,118,121,125,
                         127,129,130,133,136,140,142,144,156,157))
middle_indices <- unique(c(7,9,10,13,19,22,23,24,26,29,34,35,39,40,
                           41,48,50,58,60,64,66,67,72,73,76,80,83,92,
                           98,100,101,109,110,122,128,131,138,148,150,
                           152,162))
low_indices <- unique(c(1,2,3,4,5,6,14,16,17,18,25,28,30,36,37,38,
                        45,46,49,51,52,55,61,62,63,70,75,81,84,85,
                        86,89,90,91,93,97,99,102,104,105,106,107,108,
                        111,112,113,116,119,120,123,124,126,132,134,
                        135,137,139,141,145,146,147,149,151,153,154,
                        155,158,159,160,161,163,164))


### Biogeochemical flows (Fertilizers)
options(scipen = 999)
Fert <- as.matrix(apply(Fertilizers_inTrade_byctr, 2, sum))
Fert2 <- as.matrix(apply(Fertilizers_inTrade_byctr, 1, sum))
Fert <- as.data.frame(cbind(Fert, Fert2))

Fert$ImpShare <- Fert[,1] / sum(Fert[,1]) * 100
Fert$ExpShare <- Fert[,2] / sum(Fert[,2]) * 100
Fert$indice   <- 1:nrow(Fert)

# Compute sums by income group using pre-defined indices:
sum_high_Fert   <- sum(Fert[high_indices, 3])
sum_middle_Fert <- sum(Fert[middle_indices, 3])
sum_low_Fert    <- sum(Fert[low_indices, 3])

cat("Biogeochemical flows - Fertilizers\n")
cat("  High Income:   ", sum_high_Fert, "\n")
cat("  Middle Income: ", sum_middle_Fert, "\n")
cat("  Low Income:    ", sum_low_Fert, "\n\n")


### Change in biosphere integrity (Biodiversity loss)
Bio <- as.matrix(apply(Biodiversity_loss_inTrade_byctr, 2, sum))
Bio2 <- as.matrix(apply(Biodiversity_loss_inTrade_byctr, 1, sum))
Bio <- as.data.frame(cbind(Bio, Bio2))

Bio$ImpShare <- Bio[,1] / sum(Bio[,1]) * 100
Bio$ExpShare <- Bio[,2] / sum(Bio[,2]) * 100

sum_high_Bio   <- sum(Bio[high_indices, 3])
sum_middle_Bio <- sum(Bio[middle_indices, 3])
sum_low_Bio    <- sum(Bio[low_indices, 3])

cat("Biosphere Integrity - Biodiversity Loss\n")
cat("  High Income:   ", sum_high_Bio, "\n")
cat("  Middle Income: ", sum_middle_Bio, "\n")
cat("  Low Income:    ", sum_low_Bio, "\n\n")


### Land system change
Land <- as.matrix(apply(Land_use_inTrade_byctr, 2, sum))
Land2 <- as.matrix(apply(Land_use_inTrade_byctr, 1, sum))
Land <- as.data.frame(cbind(Land, Land2))

Land$ImpShare <- Land[,1] / sum(Land[,1]) * 100
Land$ExpShare <- Land[,2] / sum(Land[,2]) * 100

sum_high_Land   <- sum(Land[high_indices, 3])
sum_middle_Land <- sum(Land[middle_indices, 3])
sum_low_Land    <- sum(Land[low_indices, 3])

cat("Land System Change\n")
cat("  High Income:   ", sum_high_Land, "\n")
cat("  Middle Income: ", sum_middle_Land, "\n")
cat("  Low Income:    ", sum_low_Land, "\n\n")


### Blue water consumption
Blue <- as.matrix(apply(Blue_water_consumption_inTrade_byctr, 2, sum))
Blue2 <- as.matrix(apply(Blue_water_consumption_inTrade_byctr, 1, sum))
Blue <- as.data.frame(cbind(Blue, Blue2))

Blue$ImpShare <- Blue[,1] / sum(Blue[,1]) * 100
Blue$ExpShare <- Blue[,2] / sum(Blue[,2]) * 100

sum_high_Blue   <- sum(Blue[high_indices, 3])
sum_middle_Blue <- sum(Blue[middle_indices, 3])
sum_low_Blue    <- sum(Blue[low_indices, 3])

cat("Blue Water Consumption\n")
cat("  High Income:   ", sum_high_Blue, "\n")
cat("  Middle Income: ", sum_middle_Blue, "\n")
cat("  Low Income:    ", sum_low_Blue, "\n\n")


### Water stress
Stress <- as.matrix(apply(Water_stress_inTrade_byctr, 2, sum))
Stress2 <- as.matrix(apply(Water_stress_inTrade_byctr, 1, sum))
Stress <- as.data.frame(cbind(Stress, Stress2))

Stress$ImpShare <- Stress[,1] / sum(Stress[,1]) * 100
Stress$ExpShare <- Stress[,2] / sum(Stress[,2]) * 100

sum_high_Stress   <- sum(Stress[high_indices, 3])
sum_middle_Stress <- sum(Stress[middle_indices, 3])
sum_low_Stress    <- sum(Stress[low_indices, 3])

cat("Water Stress\n")
cat("  High Income:   ", sum_high_Stress, "\n")
cat("  Middle Income: ", sum_middle_Stress, "\n")
cat("  Low Income:    ", sum_low_Stress, "\n\n")


### Climate Change (GHG Emissions)
GHG <- as.matrix(apply(GHG_Emissions_inTrade_byctr, 2, sum))
GHG2 <- as.matrix(apply(GHG_Emissions_inTrade_byctr, 1, sum))
GHG <- as.data.frame(cbind(GHG, GHG2))

GHG$ImpShare <- GHG[,1] / sum(GHG[,1]) * 100
GHG$ExpShare <- GHG[,2] / sum(GHG[,2]) * 100

sum_high_GHG   <- sum(GHG[high_indices, 3])
sum_middle_GHG <- sum(GHG[middle_indices, 3])
sum_low_GHG    <- sum(GHG[low_indices, 3])

cat("Climate Change (GHG Emissions)\n")
cat("  High Income:   ", sum_high_GHG, "\n")
cat("  Middle Income: ", sum_middle_GHG, "\n")
cat("  Low Income:    ", sum_low_GHG, "\n\n")


### Novel entities
Novel <- as.matrix(apply(Chemicals_inTrade_byctr, 2, sum))
Novel2 <- as.matrix(apply(Chemicals_inTrade_byctr, 1, sum))
Novel <- as.data.frame(cbind(Novel, Novel2))

Novel$ImpShare <- Novel[,1] / sum(Novel[,1]) * 100
Novel$ExpShare <- Novel[,2] / sum(Novel[,2]) * 100

sum_high_Novel   <- sum(Novel[high_indices, 3])
sum_middle_Novel <- sum(Novel[middle_indices, 3])
sum_low_Novel    <- sum(Novel[low_indices, 3])

cat("Novel Entities\n")
cat("  High Income:   ", sum_high_Novel, "\n")
cat("  Middle Income: ", sum_middle_Novel, "\n")
cat("  Low Income:    ", sum_low_Novel, "\n")

# 3.3 - Figure 3: Sankeys -------------------------------------------------------

## Figure 3: Sankey diagram of global trade's pressure over the planetary boundaries 
# Sankeys were completely generated in the Flourish tool. Here we just show which data we used as input in Flourish

# Indices in order to separate the countries according to World Bank's regions:

# East Asia and Pacific
HighEAP <- c(11,27,42,68,82,87,117,136)
MidEAP <- c(34,72,109,148)
LowEAP <- c(4,86,89,104,105,123,124,126,160)

# Europe and Central Asia
HighECA <- c(12,15,32,42,43,44,47,53,54,56,57,59,65,69,71,74,77,79,94,95,96,103,114,115,125,127,130,140,142,143,144)
MidECA <- c(2,7,10,13,19,22,23,60,83,98,101,131,150,152)
LowECA <- c(85,149,155,158)

# Latin America and the Caribbean
HighLAC <- c(21,33,121,156)
MidLAC <- c(1,9,24,26,39,40,41,48,50,66,67,80,100,122,128,138)
LowLAC <- c(25,113,159)

# Middle East and North Africa
HighMENA <- c(8,20,78,88,118,128,133)
MidMENA <- c(76,92)
LowMENA <- c(46,49,51,70,75,81,90,97,120,145,151,161)

# North America
HighNA <- c(31,157)

# South Asia
MidSA <- c(73)
LowSA <- c(5,18,28,93,116,119)

# Sub-Saharan Africa
MidSSA <- c(29,35,58,64,110,162)
LowSSA <- c(3,6,14,16,17,30,36,37,38,45,52,55,61,62,63,84,91,99,102,106,107,108,111,112,132,134,135,137,139,141,146,147,153,154,163,164)

# Organize the regions into a list
regions <- list(
  "EAP"  = list(high = HighEAP,  midlow = c(MidEAP, LowEAP)),
  "ECA"  = list(high = HighECA,  midlow = c(MidECA, LowECA)),
  "LAC"  = list(high = HighLAC,  midlow = c(MidLAC, LowLAC)),
  "MENA" = list(high = HighMENA, midlow = c(MidMENA, LowMENA)),
  "NA"   = list(high = HighNA),
  "SA"   = list(midlow = c(MidSA, LowSA)),
  "SSA"  = list(midlow = c(MidSSA, LowSSA))
)

# Define the block (column‐group) definitions
blocks <- list(
  "High EAP"           = HighEAP,
  "Mid+Low EAP"        = c(MidEAP, LowEAP),
  "High ECA"           = HighECA,
  "Mid+Low ECA"        = c(LowECA, MidECA),
  "High LAC"           = HighLAC,
  "Mid+Low LAC"        = c(LowLAC, MidLAC),
  "High MENA"          = HighMENA,
  "Mid+Low MENA"       = c(MidMENA, LowMENA),
  "North America"      = HighNA,
  "Mid+Low SA"         = c(MidSA, LowSA),
  "Mid+Low SSA"        = c(MidSSA, LowSSA)
)

# We use a modified helper function to compute sums with source/destination
computeSums <- function(col_group, regions, M, destName) {
  # M is the indicator matrix (e.g. Fertilizers_inTrade_byctr)
  # destName is the destination label (i.e. the block name)
  out <- data.frame(source = character(),
                    destination = character(),
                    value = numeric(),
                    stringsAsFactors = FALSE)
  
  # Loop over regions in a fixed order:
  for(reg in c("EAP", "ECA", "LAC", "MENA", "NA", "SA", "SSA")) {
    if (!is.null(regions[[reg]]$high)) {
      sumVal <- sum(M[regions[[reg]]$high, col_group])
      out <- rbind(out,
                   data.frame(source = paste(reg, "(high)"),
                              destination = destName,
                              value = sumVal,
                              stringsAsFactors = FALSE))
    }
    if (!is.null(regions[[reg]]$midlow)) {
      sumVal <- sum(M[regions[[reg]]$midlow, col_group])
      out <- rbind(out,
                   data.frame(source = paste(reg, "(mid+low)"),
                              destination = destName,
                              value = sumVal,
                              stringsAsFactors = FALSE))
    }
  }
  return(out)
}

# We use a modified wrapper function to process an indicator
# Save output as CSV after processing
processIndicator <- function(M, indicatorName) {
  message("\n=== Indicator: ", indicatorName, " ===")
  outList <- list()
  
  for(blockName in names(blocks)) {
    col_grp <- blocks[[blockName]]
    df <- computeSums(col_grp, regions, M, blockName)
    outList[[blockName]] <- df
  }
  
  # Combine all results
  result <- do.call(rbind, outList)
  
  # Clean name for the file
  clean_name <- gsub(" ", "_", tolower(indicatorName))
  file_name <- paste0("sankey_", clean_name, ".csv")
  
  # Write to CSV
  write.csv(result, file = paste0("Outputs/Sankey/",file_name), row.names = FALSE)
  message("Saved CSV: ", file_name)
  
  return(result)
}

# We repeat the task for the other boundaries 
# Replace the matrix names below with your actual matrices
res_Fert <- processIndicator(Fertilizers_inTrade_byctr, "Fertilizers in Trade")
res_GHG  <- processIndicator(GHG_Emissions_inTrade_byctr, "GHG Emissions in Trade")
res_Land <- processIndicator(Land_use_inTrade_byctr, "Land Use in Trade")
res_Blue <- processIndicator(Blue_water_consumption_inTrade_byctr, "Blue Water Consumption in Trade")
res_Stress <- processIndicator(Water_stress_inTrade_byctr, "Water Stress in Trade")
res_Bio <- processIndicator(Biodiversity_loss_inTrade_byctr, "Biodiversity loss in Trade")
res_Chem <- processIndicator(Chemicals_inTrade_byctr, "Novel entities")

#  Figure 4: Radar Charts --------------------------------------------------

# Define the region indices
# (For LAC, we combine High, Mid, and Low; for SSA, SA, etc., we combine Mid and Low only)
LAC    <- c(21,33,121,156, 1,9,24,26,39,40,41,48,50,66,67,80,100,122,128,138, 25,113,159)
SSA    <- c(MidSSA, LowSSA)  # previously defined MidSSA and LowSSA
SA     <- c(MidSA, LowSA)    # previously defined MidSA and LowSA
MENA_H <- HighMENA           # previously defined HighMENA
MENA_M <- c(MidMENA, LowMENA) # previously defined MidMENA and LowMENA
EAP_H  <- HighEAP            # previously defined HighEAP
EAP_M  <- c(MidEAP, LowEAP)   # previously defined MidEAP and LowEAP
ECA_H  <- HighECA            # previously defined HighECA
ECA_M  <- c(MidECA, LowECA)   # previously defined MidECA and LowECA
NA_reg <- HighNA             # previously defined HighNA

regions_radar <- list(
  LAC         = LAC,
  SSA         = SSA,
  SA          = SA,
  NorthAmerica = NA_reg,
  MENA_H      = MENA_H,
  MENA_M      = MENA_M,
  EAP_H       = EAP_H,
  EAP_M       = EAP_M,
  ECA_H       = ECA_H,
  ECA_M       = ECA_M
)

# Define the indicator matrices
indicators <- list(
  "Fertilizers"   = Fertilizers_inTrade_byctr,
  "Biodiversity"  = Biodiversity_loss_inTrade_byctr,
  "Land Use"      = Land_use_inTrade_byctr,
  "Blue Water"    = Blue_water_consumption_inTrade_byctr,
  "Water Stress"  = Water_stress_inTrade_byctr,
  "GHG"           = GHG_Emissions_inTrade_byctr,
  "Chemicals"     = Chemicals_inTrade_byctr
)

# 3. Loop over each region and indicator to compute shares
# For each indicator, we compute the percentage share of the global total 
# coming from the rows (Exports) and from the columns (Imports)

# Create an empty list to hold the results for each region:
radar_results <- list()

for (regName in names(regions_radar)) {
  reg_idx <- regions_radar[[regName]]
  # Create a data frame to hold one radar chart’s inputs:
  df <- data.frame(
    Indicator = character(),
    Exports   = numeric(),  # row share
    Imports   = numeric(),  # column share
    stringsAsFactors = FALSE
  )
  
  for (indName in names(indicators)) {
    M <- indicators[[indName]]
    globalSum <- sum(M)
    # Compute the share of the total coming from the selected rows (Exports)
    # and from the selected columns (Imports):
    exportShare <- sum(M[reg_idx, ]) / globalSum * 100
    importShare <- sum(M[, reg_idx]) / globalSum * 100
    df <- rbind(df, data.frame(Indicator = indName,
                               Exports   = exportShare,
                               Imports   = importShare,
                               stringsAsFactors = FALSE))
  }
  radar_results[[regName]] <- df
}

# 4. Print the results for each region
if (!dir.exists("Outputs/Radar")) {
  dir.create("Outputs/Radar", recursive = TRUE)
}

# Save each element of radar_results to a CSV
for (regName in names(radar_results)) {
  file_path <- paste0("Outputs/Radar/radar_", regName, ".csv")
  write.csv(radar_results[[regName]], file = file_path, row.names = FALSE)
  message("Saved: ", file_path)
}

# Annex Calculations ------------------------------------------------------

# Reorganize data

Fertilizers_inTrade_bysec <- readRDS("Outputs/Fertilizers_inTrade_bysec.rds")
Fertilizers_inTrade_secbysec <- readRDS("Outputs/Fertilizers_inTrade_secbysec.rds")
Biodiversity_loss_inTrade_bysec <- readRDS("Outputs/Biodiversity_loss_inTrade_bysec.rds")
Biodiversity_loss_inTrade_secbysec <- readRDS("Outputs/Biodiversity_loss_inTrade_secbysec.rds")
Land_use_inTrade_bysec <- readRDS("Outputs/Land_use_inTrade_bysec.rds")
Land_use_inTrade_secbysec <- readRDS("Outputs/Land_use_inTrade_secbysec.rds")
Blue_water_consumption_inTrade_bysec <- readRDS("Outputs/Blue_water_consumption_inTrade_bysec.rds")
Blue_water_consumption_inTrade_secbysec <- readRDS("Outputs/Blue_water_consumption_inTrade_secbysec.rds")
Water_stress_inTrade_bysec <- readRDS("Outputs/Water_stress_inTrade_bysec.rds")
Water_stress_inTrade_secbysec <- readRDS("Outputs/Water_stress_inTrade_secbysec.rds")
GHG_Emissions_inTrade_bysec <- readRDS("Outputs/GHG_Emissions_inTrade_bysec.rds")
GHG_Emissions_inTrade_secbysec <- readRDS("Outputs/GHG_Emissions_inTrade_secbysec.rds")
Chemicals_inTrade_bysec <- readRDS("Outputs/Chemicals_inTrade_bysec.rds")
Chemicals_inTrade_secbysec <- readRDS("Outputs/Chemicals_inTrade_secbysec.rds")

Fert <- as.data.frame(apply(Fertilizers_inTrade_bysec, 1,sum))
Fert$Share <- Fert[,1]/sum(Fert[,1])*100
Fert2 <- as.data.frame(apply(Fertilizers_inTrade_secbysec, 2,sum))
Fert2$Share <- Fert2[,1]/sum(Fert2[,1])*100

Bio <- as.data.frame(apply(Biodiversity_loss_inTrade_bysec, 1,sum))
Bio$Share <- Bio[,1]/sum(Bio[,1])*100
Bio2 <- as.data.frame(apply(Biodiversity_loss_inTrade_secbysec, 2,sum))
Bio2$Share <- Bio2[,1]/sum(Bio2[,1])*100

Land <- as.data.frame(apply(Land_use_inTrade_bysec, 1,sum))
Land$Share <- Land[,1]/sum(Land[,1])*100
Land2 <- as.data.frame(apply(Land_use_inTrade_secbysec, 2,sum))
Land2$Share <- Land2[,1]/sum(Land2[,1])*100

Blue <- as.data.frame(apply(Blue_water_consumption_inTrade_bysec, 1,sum))
Blue$Share <- Blue[,1]/sum(Blue[,1])*100
Blue2 <- as.data.frame(apply(Blue_water_consumption_inTrade_secbysec, 2,sum))
Blue2$Share <- Blue2[,1]/sum(Blue2[,1])*100

Stress <- as.data.frame(apply(Water_stress_inTrade_bysec, 1,sum))
Stress$Share <- Stress[,1]/sum(Stress[,1])*100
Stress2 <- as.data.frame(apply(Water_stress_inTrade_secbysec, 2,sum))
Stress2$Share <- Stress2[,1]/sum(Stress2[,1])*100

GHG <- as.data.frame(apply(GHG_Emissions_inTrade_bysec, 1,sum))
GHG$Share <- GHG[,1]/sum(GHG[,1])*100
GHG2 <- as.data.frame(apply(GHG_Emissions_inTrade_secbysec, 2,sum))
GHG2$Share <- GHG2[,1]/sum(GHG2[,1])*100

Chem <- as.data.frame(apply(Chemicals_inTrade_bysec, 1,sum))
Chem$Share <- Chem[,1]/sum(Chem[,1])*100
Chem2 <- as.data.frame(apply(Chemicals_inTrade_secbysec, 2,sum))
Chem2$Share <- Chem2[,1]/sum(Chem2[,1])*100

options(scipen=999)

## Production Perspective

Clusterdata <- cbind(Fert$Share,Bio$Share,Land$Share,Blue$Share,Stress$Share,GHG$Share,Chem$Share)
#Labels <- as.data.frame(label_IO[c(1:120),3])
#rownames(Clusterdata) <- as.character(Labels[,1])
colnames(Clusterdata) <- c("Biogeochemical","Biosphere","Land system","Blue water", "Water stress","Climate change", "Novel entities")

distance <- dist(Clusterdata, method = "euclidean") #Calculating distance between observations
distance <- distance^2 #squaring distances

cluster <- hclust(distance, method = "ward.D2") #Change for single, average and Ward.D2
cbind(cluster$merge,cluster$height) #merging results of the clusters
plot(cluster) #plot of raw dendogram

n=nrow(Clusterdata) #code for creating the elbow and decide on the number of clusters
g=seq(1,n-1,1)
g=sort(g, decreasing=TRUE)
plot(cluster$height,g,type="l", ylim = c(1, 30))
axis(2, at = seq(0, 100, by = 1))

Result <- cutree(cluster,6) #Choose the number of clusters. Single = 3, Average = 7, Ward.D = 6, Ward.D2 = 6

# Figure A.2 
fviz_cluster(list(data = Clusterdata, cluster = Result)) # Plot cluster

# PCA analysis underlining the cluster
pca_result <- prcomp(Clusterdata, scale = TRUE)
summary(pca_result)
pca_result$rotation

# Figure A.3
fviz_contrib(pca_result, choice = "var", axes = 1, top = 10)
fviz_contrib(pca_result, choice = "var", axes = 2, top = 10)

# Code for biplot
biplot(pca_result, choices = 1:2, xlim = c(-7, 7), ylim = c(-7, 7), scale = 0,
       col = c("transparent", "black"), cex = c(0, 1))

# Figure A.1 
# Correlation Analysis
ggcorr(Clusterdata, method = c("everything", "spearman"), label = T, label_round = 3)
ggcorr(Clusterdata, method = c("everything", "kendall"), label = T, label_round = 3)


## Consumption Perspective

Clusterdata2 <- cbind(Fert2$Share,Bio2$Share,Land2$Share,Blue2$Share,Stress2$Share,GHG2$Share,Chem2$Share)
#Labels <- as.data.frame(label_IO[c(1:120),3])
#rownames(Clusterdata2) <- as.character(Labels[,1])
colnames(Clusterdata2) <- c("Biogeochemical","Biosphere","Land system","Blue water", "Water stress","Climate change", "Novel entities")

distance <- dist(Clusterdata2, method = "euclidean") #Calculating distance between observations
distance <- distance^2 #squaring distances

cluster <- hclust(distance, method = "ward.D2") #Change for single, average and Ward.D
cbind(cluster$merge,cluster$height) #merging results of the clusters
plot(cluster) #plot of raw dendogram

n=nrow(Clusterdata2) #code for creating the elbow and decide on the number of clusters
g=seq(1,n-1,1)
g=sort(g, decreasing=TRUE)
plot(cluster$height,g,type="l", ylim = c(1, 30))
axis(2, at = seq(0, 100, by = 1))

Result <- cutree(cluster,5) #Choose the number of clusters. Single = 5, Average = 8, Ward.D = 6, Ward.D2 = 3
fviz_cluster(list(data = Clusterdata2, cluster = Result)) # Plot nice cluster

# PCA analysis underlining the cluster
pca_result <- prcomp(Clusterdata2, scale = TRUE)
summary(pca_result)
pca_result$rotation

# Figure A.6
fviz_contrib(pca_result, choice = "var", axes = 1, top = 10)
fviz_contrib(pca_result, choice = "var", axes = 2, top = 10)

# Assume pca_result is the result of your PCA analysis
biplot(pca_result, choices = 1:2, xlim = c(-7, 7), ylim = c(-7, 7), scale = 0,
       col = c("transparent", "black"), cex = c(0, 1))

# Figure A.4
# Correlation Analysis
ggcorr(Clusterdata2, method = c("everything", "spearman"), label = T, label_round = 3)
ggcorr(Clusterdata2, method = c("everything", "kendall"), label = T,label_round = 3)




